@@ -1,5 +1,5 @@
 /*
- * Copyright 2022-2023 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2022-2025 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -8,24 +8,24 @@
  */
 
 #ifndef OSSL_QUIC_WIRE_PKT_H
-#define OSSL_QUIC_WIRE_PKT_H
+# define OSSL_QUIC_WIRE_PKT_H
 
-#include <openssl/ssl.h>
-#include "internal/packet_quic.h"
-#include "internal/quic_types.h"
+# include <openssl/ssl.h>
+# include "internal/packet_quic.h"
+# include "internal/quic_types.h"
 
-#ifndef OPENSSL_NO_QUIC
+# ifndef OPENSSL_NO_QUIC
 
-#define QUIC_VERSION_NONE ((uint32_t)0) /* Used for version negotiation */
-#define QUIC_VERSION_1 ((uint32_t)1) /* QUIC v1 */
+#  define QUIC_VERSION_NONE   ((uint32_t)0)   /* Used for version negotiation */
+#  define QUIC_VERSION_1      ((uint32_t)1)   /* QUIC v1 */
 
 /* QUIC logical packet type. These do not match wire values. */
-#define QUIC_PKT_TYPE_INITIAL 1
-#define QUIC_PKT_TYPE_0RTT 2
-#define QUIC_PKT_TYPE_HANDSHAKE 3
-#define QUIC_PKT_TYPE_RETRY 4
-#define QUIC_PKT_TYPE_1RTT 5
-#define QUIC_PKT_TYPE_VERSION_NEG 6
+#  define QUIC_PKT_TYPE_INITIAL        1
+#  define QUIC_PKT_TYPE_0RTT           2
+#  define QUIC_PKT_TYPE_HANDSHAKE      3
+#  define QUIC_PKT_TYPE_RETRY          4
+#  define QUIC_PKT_TYPE_1RTT           5
+#  define QUIC_PKT_TYPE_VERSION_NEG    6
 
 /*
  * Determine encryption level from packet type. Returns QUIC_ENC_LEVEL_NUM if
@@ -35,16 +35,16 @@ static ossl_inline ossl_unused uint32_t
 ossl_quic_pkt_type_to_enc_level(uint32_t pkt_type)
 {
     switch (pkt_type) {
-    case QUIC_PKT_TYPE_INITIAL:
-        return QUIC_ENC_LEVEL_INITIAL;
-    case QUIC_PKT_TYPE_HANDSHAKE:
-        return QUIC_ENC_LEVEL_HANDSHAKE;
-    case QUIC_PKT_TYPE_0RTT:
-        return QUIC_ENC_LEVEL_0RTT;
-    case QUIC_PKT_TYPE_1RTT:
-        return QUIC_ENC_LEVEL_1RTT;
-    default:
-        return QUIC_ENC_LEVEL_NUM;
+        case QUIC_PKT_TYPE_INITIAL:
+            return QUIC_ENC_LEVEL_INITIAL;
+        case QUIC_PKT_TYPE_HANDSHAKE:
+            return QUIC_ENC_LEVEL_HANDSHAKE;
+        case QUIC_PKT_TYPE_0RTT:
+            return QUIC_ENC_LEVEL_0RTT;
+        case QUIC_PKT_TYPE_1RTT:
+            return QUIC_ENC_LEVEL_1RTT;
+        default:
+            return QUIC_ENC_LEVEL_NUM;
     }
 }
 
@@ -52,16 +52,16 @@ static ossl_inline ossl_unused uint32_t
 ossl_quic_enc_level_to_pkt_type(uint32_t enc_level)
 {
     switch (enc_level) {
-    case QUIC_ENC_LEVEL_INITIAL:
-        return QUIC_PKT_TYPE_INITIAL;
-    case QUIC_ENC_LEVEL_HANDSHAKE:
-        return QUIC_PKT_TYPE_HANDSHAKE;
-    case QUIC_ENC_LEVEL_0RTT:
-        return QUIC_PKT_TYPE_0RTT;
-    case QUIC_ENC_LEVEL_1RTT:
-        return QUIC_PKT_TYPE_1RTT;
-    default:
-        return UINT32_MAX;
+        case QUIC_ENC_LEVEL_INITIAL:
+            return QUIC_PKT_TYPE_INITIAL;
+        case QUIC_ENC_LEVEL_HANDSHAKE:
+            return QUIC_PKT_TYPE_HANDSHAKE;
+        case QUIC_ENC_LEVEL_0RTT:
+            return QUIC_PKT_TYPE_0RTT;
+        case QUIC_ENC_LEVEL_1RTT:
+            return QUIC_PKT_TYPE_1RTT;
+        default:
+            return UINT32_MAX;
     }
 }
 
@@ -70,11 +70,11 @@ static ossl_inline ossl_unused int
 ossl_quic_pkt_type_is_encrypted(uint32_t pkt_type)
 {
     switch (pkt_type) {
-    case QUIC_PKT_TYPE_RETRY:
-    case QUIC_PKT_TYPE_VERSION_NEG:
-        return 0;
-    default:
-        return 1;
+        case QUIC_PKT_TYPE_RETRY:
+        case QUIC_PKT_TYPE_VERSION_NEG:
+            return 0;
+        default:
+            return 1;
     }
 }
 
@@ -140,9 +140,9 @@ ossl_quic_pkt_type_has_scid(uint32_t pkt_type)
  * Smallest possible QUIC packet size as per RFC (aside from version negotiation
  * packets).
  */
-#define QUIC_MIN_VALID_PKT_LEN_CRYPTO 21
-#define QUIC_MIN_VALID_PKT_LEN_VERSION_NEG 7
-#define QUIC_MIN_VALID_PKT_LEN QUIC_MIN_VALID_PKT_LEN_VERSION_NEG
+#  define QUIC_MIN_VALID_PKT_LEN_CRYPTO      21
+#  define QUIC_MIN_VALID_PKT_LEN_VERSION_NEG  7
+#  define QUIC_MIN_VALID_PKT_LEN              QUIC_MIN_VALID_PKT_LEN_VERSION_NEG
 
 typedef struct quic_pkt_hdr_ptrs_st QUIC_PKT_HDR_PTRS;
 
@@ -155,16 +155,16 @@ typedef struct quic_pkt_hdr_ptrs_st QUIC_PKT_HDR_PTRS;
  * destroyed using ossl_quic_hdr_protector_cleanup when no longer needed.
  */
 typedef struct quic_hdr_protector_st {
-    OSSL_LIB_CTX *libctx;
-    const char *propq;
-    EVP_CIPHER_CTX *cipher_ctx;
-    EVP_CIPHER *cipher;
-    uint32_t cipher_id;
+    OSSL_LIB_CTX       *libctx;
+    const char         *propq;
+    EVP_CIPHER_CTX     *cipher_ctx;
+    EVP_CIPHER         *cipher;
+    uint32_t            cipher_id;
 } QUIC_HDR_PROTECTOR;
 
-#define QUIC_HDR_PROT_CIPHER_AES_128 1
-#define QUIC_HDR_PROT_CIPHER_AES_256 2
-#define QUIC_HDR_PROT_CIPHER_CHACHA 3
+#  define QUIC_HDR_PROT_CIPHER_AES_128    1
+#  define QUIC_HDR_PROT_CIPHER_AES_256    2
+#  define QUIC_HDR_PROT_CIPHER_CHACHA     3
 
 /*
  * Initialises a header protector.
@@ -186,11 +186,11 @@ typedef struct quic_hdr_protector_st {
  * Returns 1 on success and 0 on failure.
  */
 int ossl_quic_hdr_protector_init(QUIC_HDR_PROTECTOR *hpr,
-    OSSL_LIB_CTX *libctx,
-    const char *propq,
-    uint32_t cipher_id,
-    const unsigned char *quic_hp_key,
-    size_t quic_hp_key_len);
+                                 OSSL_LIB_CTX *libctx,
+                                 const char *propq,
+                                 uint32_t cipher_id,
+                                 const unsigned char *quic_hp_key,
+                                 size_t quic_hp_key_len);
 
 /*
  * Destroys a header protector. This is also safe to call on a zero-initialized
@@ -212,7 +212,7 @@ void ossl_quic_hdr_protector_cleanup(QUIC_HDR_PROTECTOR *hpr);
  * Returns 1 on success and 0 on failure.
  */
 int ossl_quic_hdr_protector_decrypt(QUIC_HDR_PROTECTOR *hpr,
-    QUIC_PKT_HDR_PTRS *ptrs);
+                                    QUIC_PKT_HDR_PTRS *ptrs);
 
 /*
  * Applies header protection to a packet. The packet payload must already have
@@ -225,7 +225,7 @@ int ossl_quic_hdr_protector_decrypt(QUIC_HDR_PROTECTOR *hpr,
  * Returns 1 on success and 0 on failure.
  */
 int ossl_quic_hdr_protector_encrypt(QUIC_HDR_PROTECTOR *hpr,
-    QUIC_PKT_HDR_PTRS *ptrs);
+                                    QUIC_PKT_HDR_PTRS *ptrs);
 
 /*
  * Removes header protection from a packet. The packet payload must currently
@@ -248,20 +248,20 @@ int ossl_quic_hdr_protector_encrypt(QUIC_HDR_PROTECTOR *hpr,
  * Returns 1 on success and 0 on failure.
  */
 int ossl_quic_hdr_protector_decrypt_fields(QUIC_HDR_PROTECTOR *hpr,
-    const unsigned char *sample,
-    size_t sample_len,
-    unsigned char *first_byte,
-    unsigned char *pn_bytes);
+                                           const unsigned char *sample,
+                                           size_t sample_len,
+                                           unsigned char *first_byte,
+                                           unsigned char *pn_bytes);
 
 /*
  * Works analogously to ossl_hdr_protector_decrypt_fields, but applies header
  * protection instead of removing it.
  */
 int ossl_quic_hdr_protector_encrypt_fields(QUIC_HDR_PROTECTOR *hpr,
-    const unsigned char *sample,
-    size_t sample_len,
-    unsigned char *first_byte,
-    unsigned char *pn_bytes);
+                                           const unsigned char *sample,
+                                           size_t sample_len,
+                                           unsigned char *first_byte,
+                                           unsigned char *pn_bytes);
 
 /*
  * QUIC Packet Header
@@ -310,29 +310,29 @@ int ossl_quic_hdr_protector_encrypt_fields(QUIC_HDR_PROTECTOR *hpr,
  */
 typedef struct quic_pkt_hdr_st {
     /* [ALL] A QUIC_PKT_TYPE_* value. Always valid. */
-    unsigned int type : 8;
+    unsigned int    type        :8;
 
     /* [S] Value of the spin bit. Valid if (type == 1RTT). */
-    unsigned int spin_bit : 1;
+    unsigned int    spin_bit    :1;
 
     /*
      * [S] Value of the Key Phase bit in the short packet.
      * Valid if (type == 1RTT && !partial).
      */
-    unsigned int key_phase : 1;
+    unsigned int    key_phase   :1;
 
     /*
      * [1i0h] Length of packet number in bytes. This is the decoded value.
      * Valid if ((type == 1RTT || (version && type != RETRY)) && !partial).
      */
-    unsigned int pn_len : 4;
+    unsigned int    pn_len      :4;
 
     /*
      * [ALL] Set to 1 if this is a partial decode because the packet header
      * has not yet been deprotected. pn_len, pn and key_phase are not valid if
      * this is set.
      */
-    unsigned int partial : 1;
+    unsigned int    partial     :1;
 
     /*
      * [ALL] Whether the fixed bit was set. Note that only Version Negotiation
@@ -340,7 +340,7 @@ typedef struct quic_pkt_hdr_st {
      * other packet types (decode will fail if it is not set). Ignored when
      * encoding unless encoding a Version Negotiation packet.
      */
-    unsigned int fixed : 1;
+    unsigned int    fixed       :1;
 
     /*
      * The unused bits in the low 4 bits of a Retry packet header's first byte.
@@ -348,7 +348,7 @@ typedef struct quic_pkt_hdr_st {
      * representation in their header when decoding and encoding them again.
      * This is necessary to validate Retry packet headers.
      */
-    unsigned int unused : 4;
+    unsigned int    unused      :4;
 
     /*
      * The 'Reserved' bits in an Initial, Handshake, 0-RTT or 1-RTT packet
@@ -356,19 +356,19 @@ typedef struct quic_pkt_hdr_st {
      * that they are zero, as this must be done after packet protection is
      * successfully removed to avoid creating a timing channel.
      */
-    unsigned int reserved : 2;
+    unsigned int    reserved    :2;
 
     /* [L] Version field. Valid if (type != 1RTT). */
-    uint32_t version;
+    uint32_t        version;
 
     /* [ALL] The destination connection ID. Always valid. */
-    QUIC_CONN_ID dst_conn_id;
+    QUIC_CONN_ID    dst_conn_id;
 
     /*
      * [L] The source connection ID.
      * Valid if (type != 1RTT).
      */
-    QUIC_CONN_ID src_conn_id;
+    QUIC_CONN_ID    src_conn_id;
 
     /*
      * [1i0h] Relatively-encoded packet number in raw, encoded form. The correct
@@ -378,7 +378,7 @@ typedef struct quic_pkt_hdr_st {
      *
      * Valid if ((type == 1RTT || (version && type != RETRY)) && !partial).
      */
-    unsigned char pn[4];
+    unsigned char           pn[4];
 
     /*
      * [i] Token field in Initial packet. Points to memory inside the decoded
@@ -387,8 +387,8 @@ typedef struct quic_pkt_hdr_st {
      *
      * Valid if (type == INITIAL).
      */
-    const unsigned char *token;
-    size_t token_len;
+    const unsigned char    *token;
+    size_t                  token_len;
 
     /*
      * [ALL] Payload length in bytes.
@@ -399,7 +399,7 @@ typedef struct quic_pkt_hdr_st {
      * length, regardless of whether the packet type encoded or decoded uses an
      * explicit length indication.
      */
-    size_t len;
+    size_t                  len;
 
     /*
      * Pointer to start of payload data in the packet. Points to memory inside
@@ -424,7 +424,7 @@ typedef struct quic_pkt_hdr_st {
      * this case (i.e., the len field is the number of payload bytes plus the
      * number of bytes comprising the PN).
      */
-    const unsigned char *data;
+    const unsigned char    *data;
 } QUIC_PKT_HDR;
 
 /*
@@ -433,15 +433,15 @@ typedef struct quic_pkt_hdr_st {
  * needing to partially re-decode the packet header.
  */
 struct quic_pkt_hdr_ptrs_st {
-    unsigned char *raw_start; /* start of packet */
-    unsigned char *raw_sample; /* start of sampling range */
-    size_t raw_sample_len; /* maximum length of sampling range */
+    unsigned char    *raw_start;        /* start of packet */
+    unsigned char    *raw_sample;       /* start of sampling range */
+    size_t            raw_sample_len;   /* maximum length of sampling range */
 
     /*
      * Start of PN field. Guaranteed to be NULL unless at least four bytes are
      * available via this pointer.
      */
-    unsigned char *raw_pn;
+    unsigned char    *raw_pn;
 };
 
 /*
@@ -465,14 +465,23 @@ struct quic_pkt_hdr_ptrs_st {
  * QUIC_MAX_CONN_ID_LEN), this function fails when trying to decode a short
  * packet, but succeeds for long packets.
  *
+ * fail_cause is a bitmask of the reasons decode might have failed
+ * as defined below, useful when you need to interrogate parts of
+ * a header even if its otherwise undecodeable.  May be NULL.
+ *
  * Returns 1 on success and 0 on failure.
  */
+
+#  define QUIC_PKT_HDR_DECODE_DECODE_ERR  (1 << 0)
+#  define QUIC_PKT_HDR_DECODE_BAD_VERSION (1 << 1)
+
 int ossl_quic_wire_decode_pkt_hdr(PACKET *pkt,
-    size_t short_conn_id_len,
-    int partial,
-    int nodata,
-    QUIC_PKT_HDR *hdr,
-    QUIC_PKT_HDR_PTRS *ptrs);
+                                  size_t short_conn_id_len,
+                                  int partial,
+                                  int nodata,
+                                  QUIC_PKT_HDR *hdr,
+                                  QUIC_PKT_HDR_PTRS *ptrs,
+                                  uint64_t *fail_cause);
 
 /*
  * Encodes a packet header. The packet is written to pkt.
@@ -510,9 +519,9 @@ int ossl_quic_wire_decode_pkt_hdr(PACKET *pkt,
  * Returns 1 on success and 0 on failure.
  */
 int ossl_quic_wire_encode_pkt_hdr(WPACKET *pkt,
-    size_t short_conn_id_len,
-    const QUIC_PKT_HDR *hdr,
-    QUIC_PKT_HDR_PTRS *ptrs);
+                                  size_t short_conn_id_len,
+                                  const QUIC_PKT_HDR *hdr,
+                                  QUIC_PKT_HDR_PTRS *ptrs);
 
 /*
  * Retrieves only the DCID from a packet header. This is intended for demuxer
@@ -525,9 +534,9 @@ int ossl_quic_wire_encode_pkt_hdr(WPACKET *pkt,
  * Returns 1 on success and 0 on failure.
  */
 int ossl_quic_wire_get_pkt_hdr_dst_conn_id(const unsigned char *buf,
-    size_t buf_len,
-    size_t short_conn_id_len,
-    QUIC_CONN_ID *dst_conn_id);
+                                           size_t buf_len,
+                                           size_t short_conn_id_len,
+                                           QUIC_CONN_ID *dst_conn_id);
 
 /*
  * Precisely predicts the encoded length of a packet header structure.
@@ -537,7 +546,7 @@ int ossl_quic_wire_get_pkt_hdr_dst_conn_id(const unsigned char *buf,
  * ossl_quic_wire_encode_pkt_hdr() will succeed.
  */
 int ossl_quic_wire_get_encoded_pkt_hdr_len(size_t short_conn_id_len,
-    const QUIC_PKT_HDR *hdr);
+                                           const QUIC_PKT_HDR *hdr);
 
 /*
  * Packet Number Encoding
@@ -556,9 +565,9 @@ int ossl_quic_wire_get_encoded_pkt_hdr_len(size_t short_conn_id_len,
  * Returns 1 on success or 0 on failure.
  */
 int ossl_quic_wire_decode_pkt_hdr_pn(const unsigned char *enc_pn,
-    size_t enc_pn_len,
-    QUIC_PN largest_pn,
-    QUIC_PN *res_pn);
+                                     size_t enc_pn_len,
+                                     QUIC_PN largest_pn,
+                                     QUIC_PN *res_pn);
 
 /*
  * Determine how many bytes should be used to encode a PN. Returns the number of
@@ -575,15 +584,15 @@ int ossl_quic_wire_determine_pn_len(QUIC_PN pn, QUIC_PN largest_acked);
  * Returns 1 on success and 0 on failure.
  */
 int ossl_quic_wire_encode_pkt_hdr_pn(QUIC_PN pn,
-    unsigned char *enc_pn,
-    size_t enc_pn_len);
+                                     unsigned char *enc_pn,
+                                     size_t enc_pn_len);
 
 /*
  * Retry Integrity Tags
  * ====================
  */
 
-#define QUIC_RETRY_INTEGRITY_TAG_LEN 16
+#  define QUIC_RETRY_INTEGRITY_TAG_LEN    16
 
 /*
  * Validate a retry integrity tag. Returns 1 if the tag is valid.
@@ -598,9 +607,9 @@ int ossl_quic_wire_encode_pkt_hdr_pn(QUIC_PN pn,
  * the body is too short.
  */
 int ossl_quic_validate_retry_integrity_tag(OSSL_LIB_CTX *libctx,
-    const char *propq,
-    const QUIC_PKT_HDR *hdr,
-    const QUIC_CONN_ID *client_initial_dcid);
+                                           const char *propq,
+                                           const QUIC_PKT_HDR *hdr,
+                                           const QUIC_CONN_ID *client_initial_dcid);
 
 /*
  * Calculates a retry integrity tag. Returns 0 on error, for example if hdr does
@@ -619,11 +628,11 @@ int ossl_quic_validate_retry_integrity_tag(OSSL_LIB_CTX *libctx,
  * Retry Integrity Tag.
  */
 int ossl_quic_calculate_retry_integrity_tag(OSSL_LIB_CTX *libctx,
-    const char *propq,
-    const QUIC_PKT_HDR *hdr,
-    const QUIC_CONN_ID *client_initial_dcid,
-    unsigned char *tag);
+                                            const char *propq,
+                                            const QUIC_PKT_HDR *hdr,
+                                            const QUIC_CONN_ID *client_initial_dcid,
+                                            unsigned char *tag);
 
-#endif
+# endif
 
 #endif
