@@ -14,12 +14,12 @@
 
 #include "testutil.h"
 
-#define ENCRYPT 1
-#define DECRYPT 0
+#define ENCRYPT  1
+#define DECRYPT  0
 
-#define DATA_SIZE 1024
-#define MAX_IV 32
-#define BUF_SIZE (DATA_SIZE + MAX_IV)
+#define DATA_SIZE    1024
+#define MAX_IV       32
+#define BUF_SIZE     (DATA_SIZE + MAX_IV)
 
 static const unsigned char KEY[] = {
     0x51, 0x50, 0xd1, 0x77, 0x2f, 0x50, 0x83, 0x4a,
@@ -35,13 +35,13 @@ static const unsigned char IV[] = {
     0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08
 };
 
-static int do_bio_cipher(const EVP_CIPHER *cipher, const unsigned char *key,
-    const unsigned char *iv)
+static int do_bio_cipher(const EVP_CIPHER* cipher, const unsigned char* key,
+    const unsigned char* iv)
 {
     BIO *b, *mem;
     static unsigned char inp[BUF_SIZE] = { 0 };
     unsigned char out[BUF_SIZE], ref[BUF_SIZE];
-    int i, lref, len;
+    int i, lref, len, tmplen;
 
     /* Fill buffer with non-zero data so that over steps can be detected */
     if (!TEST_int_gt(RAND_bytes(inp, DATA_SIZE), 0))
@@ -77,13 +77,20 @@ static int do_bio_cipher(const EVP_CIPHER *cipher, const unsigned char *key,
         BIO_push(b, mem);
         memset(out, 0, sizeof(out));
         out[i] = ~ref[i];
-        len = BIO_read(b, out, i);
+        tmplen = BIO_read(b, out, i);
+        if (tmplen < 0)
+            goto err;
+        len = tmplen;
         /* check for overstep */
         if (!TEST_uchar_eq(out[i], (unsigned char)~ref[i])) {
             TEST_info("Encrypt overstep check failed @ operation %d", i);
             goto err;
         }
-        len += BIO_read(b, out + len, sizeof(out) - len);
+        tmplen = BIO_read(b, out + len, sizeof(out) - len);
+        if (tmplen < 0)
+            goto err;
+        len += tmplen;
+
         BIO_free_all(b);
 
         if (!TEST_mem_eq(out, len, ref, lref)) {
@@ -108,7 +115,7 @@ static int do_bio_cipher(const EVP_CIPHER *cipher, const unsigned char *key,
             goto err;
         BIO_push(b, mem);
         memset(out, 0, sizeof(out));
-        for (len = 0; (delta = BIO_read(b, out + len, i));) {
+        for (len = 0; (delta = BIO_read(b, out + len, i)); ) {
             len += delta;
         }
         BIO_free_all(b);
@@ -196,7 +203,7 @@ static int do_bio_cipher(const EVP_CIPHER *cipher, const unsigned char *key,
             goto err;
         BIO_push(b, mem);
         memset(out, 0, sizeof(out));
-        for (len = 0; (delta = BIO_read(b, out + len, i));) {
+        for (len = 0; (delta = BIO_read(b, out + len, i)); ) {
             len += delta;
         }
         BIO_free_all(b);
@@ -214,13 +221,13 @@ err:
     return 0;
 }
 
-static int do_test_bio_cipher(const EVP_CIPHER *cipher, int idx)
+static int do_test_bio_cipher(const EVP_CIPHER* cipher, int idx)
 {
     switch (idx) {
-    case 0:
-        return do_bio_cipher(cipher, KEY, NULL);
-    case 1:
-        return do_bio_cipher(cipher, KEY, IV);
+        case 0:
+            return do_bio_cipher(cipher, KEY, NULL);
+        case 1:
+            return do_bio_cipher(cipher, KEY, IV);
     }
     return 0;
 }
@@ -245,25 +252,25 @@ static int test_bio_enc_aes_256_ofb(int idx)
     return do_test_bio_cipher(EVP_aes_256_ofb(), idx);
 }
 
-#ifndef OPENSSL_NO_CHACHA
+# ifndef OPENSSL_NO_CHACHA
 static int test_bio_enc_chacha20(int idx)
 {
     return do_test_bio_cipher(EVP_chacha20(), idx);
 }
 
-#ifndef OPENSSL_NO_POLY1305
+#  ifndef OPENSSL_NO_POLY1305
 static int test_bio_enc_chacha20_poly1305(int idx)
 {
     return do_test_bio_cipher(EVP_chacha20_poly1305(), idx);
 }
-#endif
-#endif
+#  endif
+# endif
 
 static int test_bio_enc_eof_read_flush(void)
 {
     /* Length chosen to ensure base64 encoding employs padding */
     const unsigned char pbuf[] = "Attack at dawn";
-    unsigned char cbuf[16]; /* At least as long as pbuf */
+    unsigned char cbuf[16];     /* At least as long as pbuf */
     const EVP_CIPHER *cipher = EVP_aes_256_gcm();
     EVP_CIPHER_CTX *ctx = NULL;
     BIO *mem = NULL, *b64 = NULL, *cbio = NULL;
@@ -285,8 +292,7 @@ static int test_bio_enc_eof_read_flush(void)
         || !TEST_int_gt(BIO_write(cbio, pbuf, sizeof(pbuf) - 1), 0)
         || !TEST_int_gt(BIO_flush(cbio), 0)
         || !TEST_int_gt(EVP_CIPHER_CTX_ctrl(ctx, EVP_CTRL_GCM_GET_TAG,
-                            sizeof(tag), tag),
-            0))
+                                            sizeof(tag), tag), 0))
         goto end;
     BIO_free(cbio);
     BIO_free(b64);
@@ -302,18 +308,18 @@ static int test_bio_enc_eof_read_flush(void)
         || !TEST_int_gt(BIO_get_cipher_ctx(cbio, &ctx), 0)
         || !TEST_true(EVP_CipherInit_ex(ctx, cipher, NULL, KEY, IV, DECRYPT))
         || !TEST_int_gt(EVP_CIPHER_CTX_ctrl(ctx, EVP_CTRL_GCM_SET_TAG,
-                            sizeof(tag), tag),
-            0)
+                                            sizeof(tag), tag), 0)
         || !TEST_int_gt((n = BIO_read(cbio, cbuf, sizeof(cbuf))), 0)
         || !TEST_true(BIO_get_cipher_status(cbio))
         /* Evaluate both and report whether either or both failed */
-        || (!TEST_int_gt(BIO_flush(cbio), 0) + !TEST_true(BIO_get_cipher_status(cbio)))
+        || (!TEST_int_gt(BIO_flush(cbio), 0) +
+            !TEST_true(BIO_get_cipher_status(cbio)))
         || !TEST_mem_eq(cbuf, n, pbuf, sizeof(pbuf) - 1))
         goto end;
 
     ret = 1;
 
-end:
+ end:
     BIO_free(cbio);
     BIO_free(b64);
     BIO_free(mem);
@@ -326,12 +332,12 @@ int setup_tests(void)
     ADD_ALL_TESTS(test_bio_enc_aes_128_ctr, 2);
     ADD_ALL_TESTS(test_bio_enc_aes_256_cfb, 2);
     ADD_ALL_TESTS(test_bio_enc_aes_256_ofb, 2);
-#ifndef OPENSSL_NO_CHACHA
+# ifndef OPENSSL_NO_CHACHA
     ADD_ALL_TESTS(test_bio_enc_chacha20, 2);
-#ifndef OPENSSL_NO_POLY1305
+#  ifndef OPENSSL_NO_POLY1305
     ADD_ALL_TESTS(test_bio_enc_chacha20_poly1305, 2);
-#endif
-#endif
+#  endif
+# endif
     ADD_TEST(test_bio_enc_eof_read_flush);
     return 1;
 }
